aboutsummaryrefslogtreecommitdiff
path: root/source/tools/acpihelp/ahaslkey.c
diff options
context:
space:
mode:
authorJung-uk Kim <jkim@FreeBSD.org>2015-05-18 23:17:05 +0000
committerJung-uk Kim <jkim@FreeBSD.org>2015-05-18 23:17:05 +0000
commit615eb2945402758f050f1cb469181d3d22a22aa3 (patch)
tree0f95f8242a48aa24d8a795f626766746819b5227 /source/tools/acpihelp/ahaslkey.c
parent2a91972d59fb9df39eae760a853d6f5bc4065cf0 (diff)
downloadsrc-615eb2945402758f050f1cb469181d3d22a22aa3.tar.gz
src-615eb2945402758f050f1cb469181d3d22a22aa3.zip
Import ACPICA 20150515.vendor/acpica/20150515
Notes
Notes: svn path=/vendor-sys/acpica/dist/; revision=283090 svn path=/vendor-sys/acpica/20150515/; revision=283091; tag=vendor/acpica/20150515
Diffstat (limited to 'source/tools/acpihelp/ahaslkey.c')
-rw-r--r--source/tools/acpihelp/ahaslkey.c31
1 files changed, 30 insertions, 1 deletions
diff --git a/source/tools/acpihelp/ahaslkey.c b/source/tools/acpihelp/ahaslkey.c
index 502909485ce1..e15d47cd62c6 100644
--- a/source/tools/acpihelp/ahaslkey.c
+++ b/source/tools/acpihelp/ahaslkey.c
@@ -1,6 +1,7 @@
/******************************************************************************
*
* Module Name: ahaslkey - Table of all known ASL non-operator keywords
*
*****************************************************************************/
@@ -147,3 +148,31 @@ const AH_ASL_KEYWORD AslKeywordInfo[] =
":= Transfer8 | Transfer16 | Transfer8_16"},
{NULL, NULL, NULL}
};
+
+/* Preprocessor directives */
+
+const AH_DIRECTIVE_INFO PreprocessorDirectives[] =
+{
+ {"#define", "OriginalName, DefinedName"},
+ {"#elif", "Expression"},
+ {"#else", ""},
+ {"#endif", ""},
+ {"#error", "Message"},
+ {"#if", "Expression"},
+ {"#ifdef", "DefinedName"},
+ {"#ifndef", "DefinedName"},
+ {"#include", "\"Filename\""},
+ {"#include", "<Filename>"},
+ {"#includebuffer", "\"Filename\""},
+ {"#includebuffer", "<Filename>"},
+ {"#line", ""},
+ {"#pragma", "Disable error-number"},
+ {"#pragma", "Message"},
+ {"#undef", "DefinedName"},
+ {"#warning", ""},
+ {"__DATE__", "Returns current date"},
+ {"__FILE__", "Returns name of current ASL file"},
+ {"__LINE__", "Returns line number in ASL file"},
+ {"__PATH__", "Returns full pathname of current ASL file"},
+ {NULL, 0}
+};
@@ -1,6 +1,7 @@
/******************************************************************************
*
- * Module Name: ahaslkey - Table of all known ASL non-operator keywords
+ * Module Name: ahaslkey - Table of all known ASL non-operator keywords and
+ * table of iASL Preprocessor directives
*
*****************************************************************************/